@@ -8,21 +8,29 @@ class DSP(MatrixProblem):
     allowedGoals = ['minimum dominating set']
     showGoal = False
 
-    _init = False
+    _immutable = False
     
     def __setattr__(self, attr, val): 
-        if self._init: self.err('openopt DSP instances are immutable, arguments should pass to constructor or solve()')
+        if self._immutable: self.err('openopt DSP instances are immutable, arguments should pass to constructor or solve()')
         self.__dict__[attr] = val
 
     def __init__(self, *args, **kw):
         MatrixProblem.__init__(self, *args, **kw)
-        self.__init_kwargs = kw
-        self._init = True
-        
+        self._init_kwargs = kw
+        self._immutable = True
+    
+    def manage(self, *args, **kw):
+        kw['routine'] = 'manage'
+        r = self.solve(*args, **kw)
+        r.probType = self.probType
+        return r
+    
     def solve(self, *args, **kw):
-        return set_routine(self, *args, **kw)
+        r = set_routine(self, *args, **kw)
+        r.probType = self.probType
+        return r
 #        from openopt import STAB
-#        KW = self.__init_kwargs
+#        KW = self._init_kwargs
 #        KW.update(kw)
 #        P = STAB(graph, **KW)
 #        r = P.solve(*args)
