@@ -23,6 +23,8 @@ class Point:
         self.p = p
         self.x = copy(x)
         self.isMultiArray = self.x.ndim > 1
+#        if self.isMultiArray:
+#            self.x = 
         for i, arg in enumerate(args):
             setattr(self, '_' + self.__expectedArgs__[i], args[i])
         for name, val in kwargs.items():
@@ -663,7 +665,8 @@ class Point:
             
 #            print 'currBestFeasPoint is not None:', (currBestFeasPoint is not None), 'self.f() > currBestFeasPoint.f():', self.f() > currBestFeasPoint.f()
 
-            contol, fTol = self.p.contol, self.p.fTol
+            #contol, fTol = self.p.contol, self.p.fTol
+            fTol = self.p.fTol
 #            print self.f(),  currBestFeasPoint.f(), self.f() - fTol ==  currBestFeasPoint.f()
             
             if currBestFeasPoint is not None and self.f() + 0.25*fTol > currBestFeasPoint.f():
